@@ -54,13 +54,10 @@ vc_sort_order = (
     "Fossil",
     "Monotone",
     "Darcs",
-    "Arch",
-    "Codeville",
     "SVK",
     "Subversion",
     "Subversion 1.7",
     "CVS",
-    "RCS",
 )
 
 def get_vcs(location):
